@@ -27,6 +27,31 @@ segments( c(x     , x-ch/3),
 invisible( c( x, y, wd, ht ) )
 }
 
+legendbox <-
+function(x, y,
+      state = "State",
+         py = "Person-time",
+      begin = "no. begin",
+        end = "no. end",
+      trans = "Transitions",
+      rates = "\n(Rate)",
+       font = 1,
+        ...)
+{
+btxt <- paste0(state, "\n",
+                  py, "\n",
+               begin, "          ", end)
+ww <- strwidth (btxt) * 1.2
+hh <- strheight(btxt) * 1.3
+zz <- tbox(btxt,
+           x = x, y = y,
+           wd = ww,
+           ht = hh,
+         font = font,
+           ...)
+text(x + ww / 1.8, y, paste0(trans, rates), adj = 0)
+}
+
 fillarr <-
 function( x1, y1, x2, y2, gap=2, fr=0.8,
           angle=17, lwd=2, length=par("pin")[1]/30, ... )
@@ -86,7 +111,7 @@ invisible( list( x = bx1*(1-pos)+bx2*pos,
 }
 
 wh.no <-
-function( tt, i, j )
+function(tt, i, j)
 {
 ## Utility to count the number of non-NA off diagonal elements with
 ## row<i or ( col=i & col<=j )
@@ -104,9 +129,9 @@ function( obj, ... )
 
 boxes.Lexis <-
 function( obj, boxpos = FALSE,
-                wmult = 1.15,
-                hmult = 1.15,
-                  cex = 1.45,
+                wmult = 1.20,
+                hmult = 1.20 + 0.85*(!show.Y),
+                  cex = 1.40,
                show   = inherits( obj, "Lexis" ),
                show.Y = show,
               scale.Y = 1,
@@ -116,7 +141,7 @@ function( obj, boxpos = FALSE,
                show.D = show,
               scale.D = FALSE,
              digits.D = as.numeric(as.logical(scale.D)),
-               show.R = is.numeric(scale.R),
+               show.R = show & is.numeric(scale.R),
               scale.R = 1,
              digits.R = as.numeric(as.logical(scale.R)),
                DR.sep = if( show.D ) c("\n(",")") else c("",""),
@@ -126,14 +151,14 @@ function( obj, boxpos = FALSE,
                    ht,
                subset = NULL,
               exclude = NULL,
-                 font = 2,
+                 font = 1,
                   lwd = 2,
            col.txt    = par("fg"),
            col.border = col.txt,
            col.bg     = "transparent",
            col.arr    = par("fg"),
-              lwd.arr = 2,
-             font.arr = 2,
+              lwd.arr = lwd,
+             font.arr = font,
               pos.arr = 0.45,
               txt.arr = NULL,
           col.txt.arr = col.arr,
@@ -250,6 +275,12 @@ if( length(lwd.arr    )<n.tr ) lwd.arr    <- rep(lwd.arr    ,n.tr)[1:n.tr]
 if( length(font.arr   )<n.tr ) font.arr   <- rep(font.arr   ,n.tr)[1:n.tr]
 if( length(pos.arr    )<n.tr ) pos.arr    <- rep(pos.arr    ,n.tr)[1:n.tr]
 
+if( length(col.arr    )>n.tr ) col.arr    <- col.arr    [1:n.tr]
+if( length(col.txt.arr)>n.tr ) col.txt.arr<- col.txt.arr[1:n.tr]
+if( length(lwd.arr    )>n.tr ) lwd.arr    <- lwd.arr    [1:n.tr]
+if( length(font.arr   )>n.tr ) font.arr   <- font.arr   [1:n.tr]
+if( length(pos.arr    )>n.tr ) pos.arr    <- pos.arr    [1:n.tr]
+
 # Here comes the plot
 # First setting up the plot area, and restoring the plot parameters later
 opar <- par( mar=c(0,0,0,0), cex=cex )
@@ -342,9 +373,9 @@ for( i in subset ) for( j in subset )
           font=font.arr[a], col=col.txt.arr[a] )
     }
   }
-# Redraw the boxes with white background to remove any arrows
+# Redraw the boxes with white background to remove any arrows crossing
 for( i in subset ) tbox( pl.nam[i], xx[i], yy[i], wd[i], ht[i],
-                         lwd=lwd[i], col.bg=par("bg") )
+                         font=font[i], lwd=lwd[i], col.bg=par("bg") )
 # Then redraw the boxes again
 for( i in subset ) tbox( pl.nam[i], xx[i], yy[i], wd[i], ht[i],
                                 font=font[i],
@@ -410,14 +441,14 @@ for( i in 1:n.st ) b[[i]] <- with( obj$Boxes,
                             col.bg=col.bg[i] ) )
 
 # and the arrows
-for( i in 1:n.st ) for( j in 1:n.st )
-   {
-  if( !is.na(obj$Tmat[i,j]) & i!=j )
+for (i in 1:n.st ) for( j in 1:n.st )
+    {
+ if (!is.na(obj$Tmat[i,j]) & i!=j )
     {
     a <- wh.no( obj$Tmat, i, j )
     arr <- with( obj$Arrows,
            boxarr( b[[i]], b[[j]],
-                   offset=(!is.na(obj$Tmat[j,i]))*offset.arr,
+                   offset=(!is.na(obj$Tmat[i,j]))*offset.arr[a],
                    lwd=lwd.arr[a],
                    col=col.arr[a],
                    pos=pos.arr[a], ... ) )
